@@ -14,8 +14,12 @@ pub mod chrono_tz;
 pub mod color;
 #[cfg(feature = "rust_decimal")]
 pub mod decimal;
+#[cfg(feature = "either")]
+pub mod either;
 #[cfg(feature = "email_address")]
 pub mod email_address;
+#[cfg(feature = "ferroid")]
+pub mod ferroid;
 #[cfg(feature = "geo-types")]
 pub mod geo;
 #[cfg(feature = "glam")]
