@@ -1,21 +1,19 @@
-use crate::{token::InvalidEncodingError, Components, Token, Tokens};
+use crate::{
+    diagnostic::{diagnostic_url, Diagnostic, Label, Report},
+    token::EncodingError,
+    Components, InvalidEncoding, Token, Tokens,
+};
 use alloc::{
-    borrow::ToOwned,
+    borrow::{Cow, ToOwned},
+    boxed::Box,
     fmt,
     string::{String, ToString},
     vec::Vec,
 };
-use core::{borrow::Borrow, cmp::Ordering, ops::Deref, str::FromStr};
+use core::{borrow::Borrow, cmp::Ordering, iter::once, ops::Deref, str::FromStr};
+use slice::PointerIndex;
 
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                                   Pointer                                    ║
-║                                  ¯¯¯¯¯¯¯¯¯                                   ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
+mod slice;
 
 /// A JSON Pointer is a string containing a sequence of zero or more reference
 /// [`Token`]s, each prefixed by a `'/'` character.
@@ -49,11 +47,21 @@ impl core::fmt::Display for Pointer {
     }
 }
 impl Pointer {
-    /// Private constructor for strings that are known to be correctly encoded
+    /// Create a `Pointer` from a string that is known to be correctly encoded.
     ///
-    /// This is a zero-copy constructor
-    fn new<S: AsRef<str> + ?Sized>(s: &S) -> &Self {
-        unsafe { &*(core::ptr::from_ref::<str>(s.as_ref()) as *const Self) }
+    /// This is a cost-free conversion.
+    ///
+    /// ## Safety
+    /// The provided string must adhere to [RFC 6901](https://datatracker.ietf.org/doc/html/rfc6901):
+    ///
+    /// - The pointer must start with `'/'` (%x2F) unless empty
+    /// - Tokens must be properly encoded:
+    ///     - `'~'` (%x7E) must be escaped as `"~0"`
+    ///     - `'/'` (%x2F) must be escaped as `"~1"`
+    ///
+    /// For potentially fallible parsing, see [`Pointer::parse`].
+    pub unsafe fn new_unchecked<S: AsRef<str> + ?Sized>(s: &S) -> &Self {
+        &*(core::ptr::from_ref::<str>(s.as_ref()) as *const Self)
     }
 
     /// Constant reference to a root pointer
@@ -72,7 +80,8 @@ impl Pointer {
     /// ## Errors
     /// Returns a `ParseError` if the string is not a valid JSON Pointer.
     pub fn parse<S: AsRef<str> + ?Sized>(s: &S) -> Result<&Self, ParseError> {
-        validate(s.as_ref()).map(Self::new)
+        // SAFETY: we validate first
+        validate(s.as_ref()).map(|s| unsafe { Self::new_unchecked(s) })
     }
 
     /// Creates a static `Pointer` from a string.
@@ -135,7 +144,8 @@ impl Pointer {
     pub fn back(&self) -> Option<Token> {
         self.0
             .rsplit_once('/')
-            .map(|(_, back)| Token::from_encoded_unchecked(back))
+            // SAFETY: pointer is encoded
+            .map(|(_, back)| unsafe { Token::from_encoded_unchecked(back) })
     }
 
     /// Returns the last token in the `Pointer`.
@@ -152,9 +162,10 @@ impl Pointer {
         }
         self.0[1..]
             .split_once('/')
+            // SAFETY: source pointer is encoded
             .map_or_else(
-                || Token::from_encoded_unchecked(&self.0[1..]),
-                |(front, _)| Token::from_encoded_unchecked(front),
+                || unsafe { Token::from_encoded_unchecked(&self.0[1..]) },
+                |(front, _)| unsafe { Token::from_encoded_unchecked(front) },
             )
             .into()
     }
@@ -174,19 +185,33 @@ impl Pointer {
         self.0[1..]
             .find('/')
             .map_or_else(
-                || (Token::from_encoded_unchecked(&self.0[1..]), Self::root()),
+                || {
+                    (
+                        // SAFETY: source pointer is encoded
+                        unsafe { Token::from_encoded_unchecked(&self.0[1..]) },
+                        Self::root(),
+                    )
+                },
                 |idx| {
                     let (front, back) = self.0[1..].split_at(idx);
-                    (Token::from_encoded_unchecked(front), Self::new(back))
+                    (
+                        // SAFETY: source pointer is encoded
+                        unsafe { Token::from_encoded_unchecked(front) },
+                        // SAFETY: we split at a token boundary, so back is
+                        // valid pointer.
+                        unsafe { Self::new_unchecked(back) },
+                    )
                 },
             )
             .into()
     }
+
     /// Splits the `Pointer` at the given index if the character at the index is
-    /// a separator backslash (`'/'`), returning `Some((head, tail))`. Otherwise,
+    /// a separator slash (`'/'`), returning `Some((head, tail))`. Otherwise,
     /// returns `None`.
     ///
-    /// For the following JSON Pointer, the following splits are possible (0, 4, 8):
+    /// For the following JSON Pointer, the following splits are possible (0, 4,
+    /// 8):
     /// ```text
     /// /foo/bar/baz
     /// ↑   ↑   ↑
@@ -209,30 +234,66 @@ impl Pointer {
             return None;
         }
         let (head, tail) = self.0.split_at(offset);
-        Some((Self::new(head), Self::new(tail)))
+        // SAFETY: we split at a token boundary, so head and tail are valid pointers
+        unsafe { Some((Self::new_unchecked(head), Self::new_unchecked(tail))) }
     }
 
     /// Splits the `Pointer` into the parent path and the last `Token`.
     pub fn split_back(&self) -> Option<(&Self, Token)> {
-        self.0
-            .rsplit_once('/')
-            .map(|(front, back)| (Self::new(front), Token::from_encoded_unchecked(back)))
+        self.0.rsplit_once('/').map(|(front, back)| {
+            (
+                // SAFETY: we split at a token boundary, so front is a valid pointer
+                unsafe { Self::new_unchecked(front) },
+                // SAFETY: source token is encoded
+                unsafe { Token::from_encoded_unchecked(back) },
+            )
+        })
     }
 
     /// A pointer to the parent of the current path.
     pub fn parent(&self) -> Option<&Self> {
-        self.0.rsplit_once('/').map(|(front, _)| Self::new(front))
+        // SAFETY: we split at a token boundary, so front is a valid pointer
+        self.0
+            .rsplit_once('/')
+            .map(|(front, _)| unsafe { Self::new_unchecked(front) })
     }
 
     /// Returns the pointer stripped of the given suffix.
     pub fn strip_suffix<'a>(&'a self, suffix: &Self) -> Option<&'a Self> {
-        self.0.strip_suffix(&suffix.0).map(Self::new)
+        self.0
+            .strip_suffix(&suffix.0)
+            // SAFETY: the suffix is a valid pointer, so removing it from the
+            // back of another pointer will preserve token boundaries
+            .map(|s| unsafe { Self::new_unchecked(s) })
     }
 
     /// Returns the pointer stripped of the given prefix.
     pub fn strip_prefix<'a>(&'a self, prefix: &Self) -> Option<&'a Self> {
-        self.0.strip_prefix(&prefix.0).map(Self::new)
+        self.0
+            .strip_prefix(&prefix.0)
+            // SAFETY: the suffix is a valid pointer, so removing it from the
+            // front of another pointer will preserve token boundaries
+            .map(|s| unsafe { Self::new_unchecked(s) })
     }
+
+    /// Returns whether `self` has a suffix of `other`.
+    ///
+    /// Note that `Pointer::root` is only a valid suffix of itself.
+    pub fn ends_with(&self, other: &Self) -> bool {
+        (self.is_root() && other.is_root())
+            || (!other.is_root() && self.as_str().ends_with(&other.0))
+    }
+
+    /// Returns whether `self` has a prefix of `other.`
+    ///
+    /// Note that `Pointer::root` is a valid prefix of any `Pointer` (including
+    /// itself).
+    pub fn starts_with(&self, other: &Self) -> bool {
+        self.as_str().starts_with(&other.0)
+            // ensure we end at a token boundary
+            && (other.len() == self.len() || self.0.as_bytes()[other.len()] == b'/')
+    }
+
     /// Attempts to get a `Token` by the index. Returns `None` if the index is
     /// out of bounds.
     ///
@@ -240,16 +301,24 @@ impl Pointer {
     /// ```rust
     /// use jsonptr::{Pointer, Token};
     ///
-    /// let ptr = Pointer::from_static("/foo/bar");
+    /// let ptr = Pointer::from_static("/foo/bar/qux");
     /// assert_eq!(ptr.get(0), Some("foo".into()));
     /// assert_eq!(ptr.get(1), Some("bar".into()));
-    /// assert_eq!(ptr.get(2), None);
+    /// assert_eq!(ptr.get(3), None);
+    /// assert_eq!(ptr.get(..), Some(Pointer::from_static("/foo/bar/qux")));
+    /// assert_eq!(ptr.get(..1), Some(Pointer::from_static("/foo")));
+    /// assert_eq!(ptr.get(1..3), Some(Pointer::from_static("/bar/qux")));
+    /// assert_eq!(ptr.get(1..=2), Some(Pointer::from_static("/bar/qux")));
     ///
     /// let ptr = Pointer::root();
     /// assert_eq!(ptr.get(0), None);
+    /// assert_eq!(ptr.get(..), Some(Pointer::root()));
     /// ```
-    pub fn get(&self, index: usize) -> Option<Token> {
-        self.tokens().nth(index).clone()
+    pub fn get<'p, I>(&'p self, index: I) -> Option<I::Output>
+    where
+        I: PointerIndex<'p>,
+    {
+        index.get(self)
     }
 
     /// Attempts to resolve a [`R::Value`] based on the path in this [`Pointer`].
@@ -469,7 +538,7 @@ impl Pointer {
     /// See [`PointerBuf::append`] for more details.
     ///
     /// **Note**: this method allocates. If you find yourself calling it more
-    /// than once for a given pointer, consider using [`PointerBuf::append`]
+    /// than  given pointer, consider using [`PointerBuf::append`]
     /// instead.
     ///
     /// ## Examples
@@ -491,7 +560,7 @@ impl Pointer {
     ///
     /// ## Examples
     /// ```
-    /// let mut ptr = jsonptr::Pointer::from_static("/foo/bar").to_buf();
+    /// let mut ptr = jsonptr::PointerBuf::parse("/foo/bar").unwrap();
     /// assert_eq!(ptr.len(), 8);
     ///
     /// ptr.push_back("~");
@@ -515,6 +584,14 @@ impl Pointer {
     pub fn is_empty(&self) -> bool {
         self.0.is_empty()
     }
+
+    /// Converts a `Box<Pointer>` into a `PointerBuf` without copying or allocating.
+    pub fn into_buf(self: Box<Pointer>) -> PointerBuf {
+        let inner = Box::into_raw(self);
+        // SAFETY: we ensure the layout of `Pointer` is the same as `str`
+        let inner = unsafe { Box::<str>::from_raw(inner as *mut str) };
+        PointerBuf(inner.into_string())
+    }
 }
 
 #[cfg(feature = "serde")]
@@ -558,6 +635,37 @@ impl<'de: 'p, 'p> serde::Deserialize<'de> for &'p Pointer {
     }
 }
 
+macro_rules! impl_source_code {
+    ($($ty:ty),+) => {
+        $(
+            #[cfg(feature = "miette")]
+            impl miette::SourceCode for $ty {
+                fn read_span<'a>(
+                    &'a self,
+                    span: &miette::SourceSpan,
+                    context_lines_before: usize,
+                    context_lines_after: usize,
+                ) -> Result<Box<dyn miette::SpanContents<'a> + 'a>, miette::MietteError> {
+                    miette::SourceCode::read_span(
+                        self.0.as_bytes(),
+                        span,
+                        context_lines_before,
+                        context_lines_after,
+                    )
+                }
+            }
+        )*
+    };
+}
+
+impl_source_code!(Pointer, &Pointer, PointerBuf);
+
+impl<'p> From<&'p Pointer> for Cow<'p, Pointer> {
+    fn from(value: &'p Pointer) -> Self {
+        Cow::Borrowed(value)
+    }
+}
+
 impl ToOwned for Pointer {
     type Owned = PointerBuf;
 
@@ -781,16 +889,6 @@ impl<'a> IntoIterator for &'a Pointer {
     }
 }
 
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                                  PointerBuf                                  ║
-║                                 ¯¯¯¯¯¯¯¯¯¯¯¯                                 ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
-
 /// An owned, mutable [`Pointer`] (akin to `String`).
 ///
 /// This type provides methods like [`PointerBuf::push_back`] and
@@ -801,24 +899,40 @@ impl<'a> IntoIterator for &'a Pointer {
 pub struct PointerBuf(String);
 
 impl PointerBuf {
+    /// Creates a new `PointerBuf` pointing to a document root.
+    ///
+    /// This is an alias to [`Self::new`].
+    pub fn root() -> Self {
+        Self::new()
+    }
+
     /// Creates a new `PointerBuf` pointing to a document root.
     pub fn new() -> Self {
         Self(String::new())
     }
 
+    /// Create a `PointerBuf` from a string that is known to be correctly encoded.
+    ///
+    /// ## Safety
+    /// The provided string must adhere to RFC 6901.
+    pub unsafe fn new_unchecked(s: impl Into<String>) -> Self {
+        Self(s.into())
+    }
+
     /// Attempts to parse a string into a `PointerBuf`.
     ///
     /// ## Errors
-    /// Returns a [`ParseError`] if the string is not a valid JSON Pointer.
-    pub fn parse<S: AsRef<str> + ?Sized>(s: &S) -> Result<Self, ParseError> {
-        Pointer::parse(&s).map(Pointer::to_buf)
+    /// Returns a [`RichParseError`] if the string is not a valid JSON Pointer.
+    pub fn parse(s: impl Into<String>) -> Result<Self, RichParseError> {
+        let s = s.into();
+        match validate(&s) {
+            Ok(_) => Ok(Self(s)),
+            Err(err) => Err(err.into_report(s)),
+        }
     }
 
     /// Creates a new `PointerBuf` from a slice of non-encoded strings.
-    pub fn from_tokens<'a, T>(tokens: impl IntoIterator<Item = T>) -> Self
-    where
-        T: Into<Token<'a>>,
-    {
+    pub fn from_tokens<'t>(tokens: impl IntoIterator<Item: Into<Token<'t>>>) -> Self {
         let mut inner = String::new();
         for t in tokens.into_iter().map(Into::into) {
             inner.push('/');
@@ -847,7 +961,8 @@ impl PointerBuf {
     /// Removes and returns the last `Token` in the `Pointer` if it exists.
     pub fn pop_back(&mut self) -> Option<Token<'static>> {
         if let Some(idx) = self.0.rfind('/') {
-            let back = Token::from_encoded_unchecked(self.0.split_off(idx + 1));
+            // SAFETY: source pointer is encoded
+            let back = unsafe { Token::from_encoded_unchecked(self.0.split_off(idx + 1)) };
             self.0.pop(); // remove trailing `/`
             Some(back)
         } else {
@@ -865,8 +980,10 @@ impl PointerBuf {
             } else {
                 core::mem::take(&mut self.0)
             };
-            token.remove(0); // remove leading `/`
-            Token::from_encoded_unchecked(token)
+            // remove leading `/`
+            token.remove(0);
+            // SAFETY: source pointer is encoded
+            unsafe { Token::from_encoded_unchecked(token) }
         })
     }
 
@@ -939,7 +1056,16 @@ impl Borrow<Pointer> for PointerBuf {
 impl Deref for PointerBuf {
     type Target = Pointer;
     fn deref(&self) -> &Self::Target {
-        Pointer::new(&self.0)
+        // SAFETY: we hold a valid pointer
+        unsafe { Pointer::new_unchecked(self.0.as_str()) }
+    }
+}
+
+impl From<PointerBuf> for Box<Pointer> {
+    fn from(value: PointerBuf) -> Self {
+        let s = value.0.into_boxed_str();
+        // SAFETY: we ensure that the layout of `str` is the same as `Pointer`
+        unsafe { Box::from_raw(Box::into_raw(s) as *mut Pointer) }
     }
 }
 
@@ -965,6 +1091,12 @@ impl serde::Serialize for PointerBuf {
     }
 }
 
+impl From<PointerBuf> for Cow<'static, Pointer> {
+    fn from(value: PointerBuf) -> Self {
+        Cow::Owned(value)
+    }
+}
+
 impl From<Token<'_>> for PointerBuf {
     fn from(t: Token) -> Self {
         PointerBuf::from_tokens([t])
@@ -1018,80 +1150,25 @@ impl core::fmt::Display for PointerBuf {
     }
 }
 
-const fn validate(value: &str) -> Result<&str, ParseError> {
-    if value.is_empty() {
-        return Ok(value);
-    }
-    let bytes = value.as_bytes();
-    if bytes[0] != b'/' {
-        return Err(ParseError::NoLeadingBackslash);
-    }
-    let mut ptr_offset = 0; // offset within the pointer of the most recent '/' separator
-    let mut tok_offset = 0; // offset within the current token
+/// Indicates that a [`Pointer`] was unable to be parsed due to not containing
+/// a leading slash (`'/'`).
+#[derive(Debug, PartialEq, Eq, Clone, Copy)]
+pub struct NoLeadingSlash;
 
-    let bytes = value.as_bytes();
-    let mut i = 0;
-    while i < bytes.len() {
-        match bytes[i] {
-            b'/' => {
-                // backslashes ('/') separate tokens
-                // we increment the ptr_offset to point to this character
-                ptr_offset = i;
-                // and reset the token offset
-                tok_offset = 0;
-            }
-            b'~' => {
-                // if the character is a '~', then the next character must be '0' or '1'
-                // otherwise the encoding is invalid and `InvalidEncodingError` is returned
-                if i + 1 >= bytes.len() || (bytes[i + 1] != b'0' && bytes[i + 1] != b'1') {
-                    // the pointer is not properly encoded
-                    //
-                    // we use the pointer offset, which points to the last
-                    // encountered separator, as the offset of the error.
-                    // The source `InvalidEncodingError` then uses the token
-                    // offset.
-                    //
-                    // "/foo/invalid~encoding"
-                    //      ^       ^
-                    //      |       |
-                    //  ptr_offset  |
-                    //          tok_offset
-                    //
-                    return Err(ParseError::InvalidEncoding {
-                        offset: ptr_offset,
-                        source: InvalidEncodingError { offset: tok_offset },
-                    });
-                }
-                // already checked the next character, so we skip it
-                i += 1;
-                // incrementing the pointer offset since the next byte has
-                // already been checked
-                tok_offset += 1;
-            }
-            _ => {}
-        }
-        i += 1;
-        // not a separator so we increment the token offset
-        tok_offset += 1;
+impl fmt::Display for NoLeadingSlash {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(
+            f,
+            "json pointer must start with a slash ('/') and is not empty"
+        )
     }
-    Ok(value)
 }
 
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                                  ParseError                                  ║
-║                                 ¯¯¯¯¯¯¯¯¯¯¯¯                                 ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
-
 /// Indicates that a `Pointer` was malformed and unable to be parsed.
 #[derive(Debug, PartialEq)]
 pub enum ParseError {
-    /// `Pointer` did not start with a backslash (`'/'`).
-    NoLeadingBackslash,
+    /// `Pointer` did not start with a slash (`'/'`).
+    NoLeadingSlash,
 
     /// `Pointer` contained invalid encoding (e.g. `~` not followed by `0` or
     /// `1`).
@@ -1100,28 +1177,85 @@ pub enum ParseError {
         /// the invalid encoding
         offset: usize,
         /// The source `InvalidEncodingError`
-        source: InvalidEncodingError,
+        source: EncodingError,
     },
 }
 
+impl ParseError {
+    /// Offset of the partial pointer starting with the token that contained the
+    /// invalid encoding
+    pub fn offset(&self) -> usize {
+        match self {
+            Self::NoLeadingSlash => 0,
+            Self::InvalidEncoding { offset, .. } => *offset,
+        }
+    }
+    /// Length of the invalid encoding
+    pub fn invalid_encoding_len(&self, subject: &str) -> usize {
+        match self {
+            Self::NoLeadingSlash => 0,
+            Self::InvalidEncoding { offset, .. } => {
+                if *offset < subject.len() - 1 {
+                    2
+                } else {
+                    1
+                }
+            }
+        }
+    }
+}
+
+impl Diagnostic for ParseError {
+    type Subject = String;
+
+    fn url() -> &'static str {
+        diagnostic_url!(struct ParseError)
+    }
+
+    fn labels(&self, subject: &Self::Subject) -> Option<Box<dyn Iterator<Item = Label>>> {
+        let offset = self.complete_offset();
+        let len = self.invalid_encoding_len(subject);
+        let text = match self {
+            ParseError::NoLeadingSlash => "must start with a slash ('/')",
+            ParseError::InvalidEncoding { .. } => "'~' must be followed by '0' or '1'",
+        }
+        .to_string();
+        Some(Box::new(once(Label::new(text, offset, len))))
+    }
+}
+
+#[cfg(feature = "miette")]
+impl miette::Diagnostic for ParseError {}
+
 impl fmt::Display for ParseError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            Self::NoLeadingBackslash { .. } => {
+            Self::NoLeadingSlash { .. } => {
                 write!(
                     f,
-                    "json pointer is malformed as it does not start with a backslash ('/')"
+                    "json pointer failed to parse; does not start with a slash ('/') and is not empty"
+                )
+            }
+            Self::InvalidEncoding { offset, .. } => {
+                write!(
+                    f,
+                    "json pointer failed to parse; the first token in the partial-pointer starting at offset {offset} is malformed"
                 )
             }
-            Self::InvalidEncoding { source, .. } => write!(f, "{source}"),
         }
     }
 }
 
 impl ParseError {
-    /// Returns `true` if this error is `NoLeadingBackslash`
+    #[deprecated(note = "renamed to `is_no_leading_slash`", since = "0.7.0")]
+    /// Returns `true` if this error is `NoLeadingSlash`
     pub fn is_no_leading_backslash(&self) -> bool {
-        matches!(self, Self::NoLeadingBackslash { .. })
+        matches!(self, Self::NoLeadingSlash { .. })
+    }
+
+    /// Returns `true` if this error is `NoLeadingSlash`
+    pub fn is_no_leading_slash(&self) -> bool {
+        matches!(self, Self::NoLeadingSlash { .. })
     }
 
     /// Returns `true` if this error is `InvalidEncoding`    
@@ -1143,7 +1277,7 @@ impl ParseError {
     /// ```
     pub fn pointer_offset(&self) -> usize {
         match *self {
-            Self::NoLeadingBackslash { .. } => 0,
+            Self::NoLeadingSlash { .. } => 0,
             Self::InvalidEncoding { offset, .. } => offset,
         }
     }
@@ -1163,7 +1297,7 @@ impl ParseError {
     /// ```
     pub fn source_offset(&self) -> usize {
         match self {
-            Self::NoLeadingBackslash { .. } => 0,
+            Self::NoLeadingSlash { .. } => 0,
             Self::InvalidEncoding { source, .. } => source.offset,
         }
     }
@@ -1189,20 +1323,13 @@ impl std::error::Error for ParseError {
     fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
         match self {
             Self::InvalidEncoding { source, .. } => Some(source),
-            Self::NoLeadingBackslash => None,
+            Self::NoLeadingSlash => None,
         }
     }
 }
 
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                              ReplaceTokenError                               ║
-║                             ¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯¯                              ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
+/// A rich error type that includes the original string that failed to parse.
+pub type RichParseError = Report<ParseError>;
 
 /// Returned from [`PointerBuf::replace`] when the provided index is out of
 /// bounds.
@@ -1223,15 +1350,71 @@ impl fmt::Display for ReplaceError {
 #[cfg(feature = "std")]
 impl std::error::Error for ReplaceError {}
 
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                                    Tests                                     ║
-║                                   ¯¯¯¯¯¯¯                                    ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
+const fn validate(value: &str) -> Result<&str, ParseError> {
+    if value.is_empty() {
+        return Ok(value);
+    }
+    if let Err(err) = validate_bytes(value.as_bytes(), 0) {
+        return Err(err);
+    }
+    Ok(value)
+}
+
+const fn validate_bytes(bytes: &[u8], offset: usize) -> Result<(), ParseError> {
+    if bytes[0] != b'/' && offset == 0 {
+        return Err(ParseError::NoLeadingSlash);
+    }
+
+    let mut ptr_offset = offset; // offset within the pointer of the most recent '/' separator
+    let mut tok_offset = 0; // offset within the current token
+
+    let mut i = offset;
+    while i < bytes.len() {
+        match bytes[i] {
+            b'/' => {
+                ptr_offset = i;
+                // and reset the token offset
+                tok_offset = 0;
+            }
+            b'~' => {
+                // if the character is a '~', then the next character must be '0' or '1'
+                // otherwise the encoding is invalid and `InvalidEncodingError` is returned
+                if i + 1 >= bytes.len() || (bytes[i + 1] != b'0' && bytes[i + 1] != b'1') {
+                    // the pointer is not properly encoded
+                    //
+                    // we use the pointer offset, which points to the last
+                    // encountered separator, as the offset of the error.
+                    // The source `InvalidEncodingError` then uses the token
+                    // offset.
+                    //
+                    // "/foo/invalid~encoding"
+                    //      ^       ^
+                    //      |       |
+                    //  ptr_offset  |
+                    //          tok_offset
+                    //
+                    return Err(ParseError::InvalidEncoding {
+                        offset: ptr_offset,
+                        source: EncodingError {
+                            offset: tok_offset,
+                            source: InvalidEncoding::Tilde,
+                        },
+                    });
+                }
+                // already checked the next character, so we skip it
+                i += 1;
+                // incrementing the pointer offset since the next byte has
+                // already been checked
+                tok_offset += 1;
+            }
+            _ => {}
+        }
+        i += 1;
+        // not a separator so we increment the token offset
+        tok_offset += 1;
+    }
+    Ok(())
+}
 
 #[cfg(test)]
 mod tests {
@@ -1247,35 +1430,88 @@ mod tests {
         let _ = Pointer::from_static("foo/bar");
     }
 
+    #[test]
+    fn root_is_alias_of_new_pathbuf() {
+        assert_eq!(PointerBuf::root(), PointerBuf::new());
+    }
+
+    #[test]
+    fn from_unchecked_pathbuf() {
+        let s = "/foo/bar/0";
+        assert_eq!(
+            unsafe { PointerBuf::new_unchecked(String::from(s)) },
+            PointerBuf::parse(s).unwrap()
+        );
+    }
+
     #[test]
     fn strip_suffix() {
-        let p = Pointer::new("/example/pointer/to/some/value");
-        let stripped = p.strip_suffix(Pointer::new("/to/some/value")).unwrap();
+        let p = Pointer::from_static("/example/pointer/to/some/value");
+        let stripped = p
+            .strip_suffix(Pointer::from_static("/to/some/value"))
+            .unwrap();
         assert_eq!(stripped, "/example/pointer");
     }
 
     #[test]
     fn strip_prefix() {
-        let p = Pointer::new("/example/pointer/to/some/value");
-        let stripped = p.strip_prefix(Pointer::new("/example/pointer")).unwrap();
+        let p = Pointer::from_static("/example/pointer/to/some/value");
+        let stripped = p
+            .strip_prefix(Pointer::from_static("/example/pointer"))
+            .unwrap();
         assert_eq!(stripped, "/to/some/value");
     }
 
     #[test]
-    fn parse_error_is_no_leading_backslash() {
-        let err = ParseError::NoLeadingBackslash;
-        assert!(err.is_no_leading_backslash());
-        assert!(!err.is_invalid_encoding());
+    fn ends_with() {
+        // positive cases
+        let p = Pointer::from_static("/foo/bar");
+        let q = Pointer::from_static("/bar");
+        assert!(p.ends_with(q));
+        let q = Pointer::from_static("/foo/bar");
+        assert!(p.ends_with(q));
+
+        // negative cases
+        let q = Pointer::from_static("/barz");
+        assert!(!p.ends_with(q));
+        let q = Pointer::from_static("/");
+        assert!(!p.ends_with(q));
+        let q = Pointer::from_static("");
+        assert!(!p.ends_with(q));
+        let q = Pointer::from_static("/qux/foo/bar");
+        assert!(!p.ends_with(q));
+
+        // edge case - both root
+        let p = Pointer::root();
+        let q = Pointer::root();
+        assert!(p.ends_with(q));
     }
 
     #[test]
-    fn parse_error_is_invalid_encoding() {
-        let err = ParseError::InvalidEncoding {
-            offset: 0,
-            source: InvalidEncodingError { offset: 1 },
-        };
-        assert!(!err.is_no_leading_backslash());
-        assert!(err.is_invalid_encoding());
+    fn starts_with() {
+        // positive cases
+        let p = Pointer::from_static("/foo/bar");
+        let q = Pointer::from_static("/foo");
+        assert!(p.starts_with(q));
+        let q = Pointer::from_static("/foo/bar");
+        assert!(p.starts_with(q));
+
+        // negative cases
+        let q = Pointer::from_static("/");
+        assert!(!p.starts_with(q));
+        let q = Pointer::from_static("/fo");
+        assert!(!p.starts_with(q));
+        let q = Pointer::from_static("/foo/");
+        assert!(!p.starts_with(q));
+
+        // edge cases: other is root
+        let p = Pointer::root();
+        let q = Pointer::root();
+        assert!(p.starts_with(q));
+        let p = Pointer::from_static("/");
+        assert!(p.starts_with(q));
+        let p = Pointer::from_static("/any/thing");
+        assert!(p.starts_with(q));
     }
 
     #[test]
@@ -1292,26 +1528,35 @@ mod tests {
             ("/foo/bar/baz/~10", Ok("/foo/bar/baz/~10")),
             ("/foo/bar/baz/~11", Ok("/foo/bar/baz/~11")),
             ("/foo/bar/baz/~1/~0", Ok("/foo/bar/baz/~1/~0")),
-            ("missing-slash", Err(ParseError::NoLeadingBackslash)),
+            ("missing-slash", Err(ParseError::NoLeadingSlash)),
             (
                 "/~",
                 Err(ParseError::InvalidEncoding {
                     offset: 0,
-                    source: InvalidEncodingError { offset: 1 },
+                    source: EncodingError {
+                        offset: 1,
+                        source: InvalidEncoding::Tilde,
+                    },
                 }),
             ),
             (
                 "/~2",
                 Err(ParseError::InvalidEncoding {
                     offset: 0,
-                    source: InvalidEncodingError { offset: 1 },
+                    source: EncodingError {
+                        offset: 1,
+                        source: InvalidEncoding::Tilde,
+                    },
                 }),
             ),
             (
                 "/~a",
                 Err(ParseError::InvalidEncoding {
                     offset: 0,
-                    source: InvalidEncodingError { offset: 1 },
+                    source: EncodingError {
+                        offset: 1,
+                        source: InvalidEncoding::Tilde,
+                    },
                 }),
             ),
         ];
@@ -1336,25 +1581,6 @@ mod tests {
         assert!(err.source().is_none());
     }
 
-    #[test]
-    #[cfg(feature = "std")]
-    fn parse_error_source() {
-        use std::error::Error;
-        let err = Pointer::parse("/foo/invalid~encoding").unwrap_err();
-        assert!(err.source().is_some());
-        let source = err.source().unwrap();
-        assert!(source.is::<InvalidEncodingError>());
-
-        let err = Pointer::parse("no-leading/slash").unwrap_err();
-        assert!(err.source().is_none());
-    }
-
-    #[test]
-    fn pointerbuf_as_pointer_returns_pointer() {
-        let ptr = PointerBuf::parse("/foo/bar").unwrap();
-        assert_eq!(ptr.as_ptr(), ptr);
-    }
-
     #[test]
     fn pointer_buf_clear() {
         let mut ptr = PointerBuf::from_tokens(["foo", "bar"]);
@@ -1424,12 +1650,6 @@ mod tests {
         assert_eq!(ptr, "");
     }
 
-    #[test]
-    fn display_replace_token_error() {
-        let err = ReplaceError { index: 3, count: 2 };
-        assert_eq!(format!("{err}"), "index 3 is out of bounds (2)");
-    }
-
     #[test]
     fn pop_front_works_with_empty_strings() {
         {
@@ -1437,13 +1657,13 @@ mod tests {
 
             assert_eq!(ptr.tokens().count(), 3);
             let mut token = ptr.pop_front();
-            assert_eq!(token, Some(Token::from_encoded_unchecked("bar")));
+            assert_eq!(token, Some(Token::new("bar")));
             assert_eq!(ptr.tokens().count(), 2);
             token = ptr.pop_front();
-            assert_eq!(token, Some(Token::from_encoded_unchecked("")));
+            assert_eq!(token, Some(Token::new("")));
             assert_eq!(ptr.tokens().count(), 1);
             token = ptr.pop_front();
-            assert_eq!(token, Some(Token::from_encoded_unchecked("")));
+            assert_eq!(token, Some(Token::new("")));
             assert_eq!(ptr.tokens().count(), 0);
             assert_eq!(ptr, Pointer::root());
         }
@@ -1528,16 +1748,6 @@ mod tests {
         assert_eq!(ptr, into);
     }
 
-    #[test]
-    fn default() {
-        let ptr = PointerBuf::default();
-        assert_eq!(ptr, "");
-        assert_eq!(ptr.count(), 0);
-
-        let ptr = <&Pointer>::default();
-        assert_eq!(ptr, "");
-    }
-
     #[test]
     #[cfg(all(feature = "serde", feature = "json"))]
     fn to_json_value() {
@@ -1630,7 +1840,7 @@ mod tests {
     fn replace_token_out_of_bounds() {
         let mut ptr = PointerBuf::from_tokens(["foo", "bar"]);
         assert!(ptr.replace(2, "baz").is_err());
-        assert_eq!(ptr, PointerBuf::from_tokens(["foo", "bar"])); // Ensure original pointer is unchanged
+        assert_eq!(ptr, PointerBuf::from_tokens(["foo", "bar"])); // Ensure subjectal pointer is unchanged
     }
 
     #[test]
@@ -1727,6 +1937,7 @@ mod tests {
     #[test]
     #[cfg(feature = "json")]
     fn into_value() {
+        use alloc::string::ToString;
         use serde_json::Value;
         let ptr = Pointer::from_static("/foo/bar");
         let value: Value = ptr.into();
@@ -1753,7 +1964,7 @@ mod tests {
 
     #[quickcheck]
     fn qc_pop_and_push(mut ptr: PointerBuf) -> bool {
-        let original_ptr = ptr.clone();
+        let subjectal_ptr = ptr.clone();
         let mut tokens = Vec::with_capacity(ptr.count());
         while let Some(token) = ptr.pop_back() {
             tokens.push(token);
@@ -1764,7 +1975,7 @@ mod tests {
         for token in tokens.drain(..) {
             ptr.push_front(token);
         }
-        if ptr != original_ptr {
+        if ptr != subjectal_ptr {
             return false;
         }
         while let Some(token) = ptr.pop_front() {
@@ -1776,7 +1987,7 @@ mod tests {
         for token in tokens {
             ptr.push_back(token);
         }
-        ptr == original_ptr
+        ptr == subjectal_ptr
     }
 
     #[quickcheck]
@@ -1903,10 +2114,6 @@ mod tests {
 
         let invalid = serde_json::from_str::<&Pointer>("\"foo/bar\"");
         assert!(invalid.is_err());
-        assert_eq!(
-            invalid.unwrap_err().to_string(),
-            "failed to parse json pointer\n\ncaused by:\njson pointer is malformed as it does not start with a backslash ('/') at line 1 column 9"
-        );
     }
 
     #[test]
@@ -2089,13 +2296,6 @@ mod tests {
             assert_eq!(intersection, base);
         }
     }
-    #[test]
-    fn parse_error_display() {
-        assert_eq!(
-            ParseError::NoLeadingBackslash.to_string(),
-            "json pointer is malformed as it does not start with a backslash ('/')"
-        );
-    }
 
     #[test]
     fn into_iter() {
@@ -2135,4 +2335,19 @@ mod tests {
         let borrowed: &Pointer = ptr.borrow();
         assert_eq!(borrowed, "/foo/bar");
     }
+
+    #[test]
+    fn from_box_to_buf() {
+        let subjectal = PointerBuf::parse("/foo/bar/0").unwrap();
+        let boxed: Box<Pointer> = subjectal.clone().into();
+        let unboxed = boxed.into_buf();
+        assert_eq!(subjectal, unboxed);
+    }
+
+    #[test]
+    #[cfg(feature = "miette")]
+    fn quick_miette_spike() {
+        let err = PointerBuf::parse("hello-world").unwrap_err();
+        println!("{:?}", miette::Report::from(err));
+    }
 }
