@@ -3,12 +3,13 @@
 //! A module that provides utility functions for computing hashes using the
 //! [RustCrypto/hashes](https://github.com/RustCrypto/hashes) library.
 //!
-//! This module provides several functions that wrap around the hashing algorithms provided by the
-//! `RustCrypto` library. These functions allow you to easily compute the hash of a file, or a
-//! stream of bytes using a variety of hashing algorithms.
+//! This module provides several functions that wrap around the hashing
+//! algorithms provided by the `RustCrypto` library. These functions allow you
+//! to easily compute the hash of a file, or a stream of bytes using a variety
+//! of hashing algorithms.
 //!
-//! By utilizing the [`Digest`] trait, any hashing algorithm that implements that trait can be used
-//! with the functions provided in this crate.
+//! By utilizing the [`Digest`] trait, any hashing algorithm that implements
+//! that trait can be used with the functions provided in this crate.
 //!
 //! # Examples
 //!
@@ -29,10 +30,11 @@
 //! # Available functions
 //!
 //! - [`compute_file_digest`]: Computes the hash of a file on disk.
-//! - [`parse_digest_from_hex`]: Given a hex representation of a digest, parses it to bytes.
-//! - [`HashingWriter`]: An object that wraps a writable object and implements [`Write`] and
-//!   [`::tokio::io::AsyncWrite`]. It forwards the data to the wrapped object but also computes the hash of the
-//!   content on the fly.
+//! - [`parse_digest_from_hex`]: Given a hex representation of a digest, parses
+//!   it to bytes.
+//! - [`HashingWriter`]: An object that wraps a writable object and implements
+//!   [`Write`] and [`::tokio::io::AsyncWrite`]. It forwards the data to the
+//!   wrapped object but also computes the hash of the content on the fly.
 //!
 //! For more information on the hashing algorithms provided by the
 //! [RustCrypto/hashes](https://github.com/RustCrypto/hashes) library, see the documentation for
@@ -44,14 +46,15 @@ mod tokio;
 #[cfg(feature = "serde")]
 pub mod serde;
 
+use std::{
+    fs::File,
+    io::{Read, Write},
+    path::Path,
+};
+
+use blake2::{digest::consts::U32, Blake2b, Blake2bMac};
 pub use digest;
-
-use blake2::digest::consts::U32;
-use blake2::{Blake2b, Blake2bMac};
 use digest::{Digest, Output};
-use std::io::Read;
-use std::{fs::File, io::Write, path::Path};
-
 pub use md5::Md5;
 pub use sha2::Sha256;
 
@@ -113,12 +116,13 @@ pub fn parse_digest_from_hex<D: Digest>(str: &str) -> Option<Output<D>> {
     }
 }
 
-/// A simple object that provides a [`Write`] implementation that also immediately hashes the bytes
-/// written to it. Call [`HashingWriter::finalize`] to retrieve both the original `impl Write`
-/// object as well as the hash.
+/// A simple object that provides a [`Write`] implementation that also
+/// immediately hashes the bytes written to it. Call [`HashingWriter::finalize`]
+/// to retrieve both the original `impl Write` object as well as the hash.
 ///
-/// If the `tokio` feature is enabled this object also implements [`::tokio::io::AsyncWrite`] which
-/// allows you to use it in an async context as well.
+/// If the `tokio` feature is enabled this object also implements
+/// [`::tokio::io::AsyncWrite`] which allows you to use it in an async context
+/// as well.
 pub struct HashingWriter<W, D: Digest> {
     writer: W,
     hasher: D,
@@ -135,8 +139,8 @@ impl<W, D: Digest + Default> HashingWriter<W, D> {
 }
 
 impl<W, D: Digest> HashingWriter<W, D> {
-    /// Consumes this instance and returns the original writer and the hash of all bytes written to
-    /// this instance.
+    /// Consumes this instance and returns the original writer and the hash of
+    /// all bytes written to this instance.
     pub fn finalize(self) -> (W, Output<D>) {
         (self.writer, self.hasher.finalize())
     }
@@ -145,7 +149,8 @@ impl<W, D: Digest> HashingWriter<W, D> {
 impl<W: Write, D: Digest> Write for HashingWriter<W, D> {
     fn write(&mut self, buf: &[u8]) -> std::io::Result<usize> {
         let bytes = self.writer.write(buf)?;
-        self.hasher.update(&buf[..bytes]);
+        self.hasher
+            .update(buf.get(..bytes).expect("safe because bytes <= buf"));
         Ok(bytes)
     }
 
@@ -154,12 +159,13 @@ impl<W: Write, D: Digest> Write for HashingWriter<W, D> {
     }
 }
 
-/// A simple object that provides a [`Read`] implementation that also immediately hashes the bytes
-/// read from it. Call [`HashingReader::finalize`] to retrieve both the original `impl Read`
-/// object as well as the hash.
+/// A simple object that provides a [`Read`] implementation that also
+/// immediately hashes the bytes read from it. Call [`HashingReader::finalize`]
+/// to retrieve both the original `impl Read` object as well as the hash.
 ///
-/// If the `tokio` feature is enabled this object also implements [`::tokio::io::AsyncRead`] which
-/// allows you to use it in an async context as well.
+/// If the `tokio` feature is enabled this object also implements
+/// [`::tokio::io::AsyncRead`] which allows you to use it in an async context as
+/// well.
 pub struct HashingReader<R, D: Digest> {
     reader: R,
     hasher: D,
@@ -176,8 +182,8 @@ impl<R, D: Digest + Default> HashingReader<R, D> {
 }
 
 impl<R, D: Digest> HashingReader<R, D> {
-    /// Consumes this instance and returns the original reader and the hash of all bytes read from
-    /// this instance.
+    /// Consumes this instance and returns the original reader and the hash of
+    /// all bytes read from this instance.
     pub fn finalize(self) -> (R, Output<D>) {
         (self.reader, self.hasher.finalize())
     }
@@ -186,17 +192,22 @@ impl<R, D: Digest> HashingReader<R, D> {
 impl<R: Read, D: Digest> Read for HashingReader<R, D> {
     fn read(&mut self, buf: &mut [u8]) -> std::io::Result<usize> {
         let bytes_read = self.reader.read(buf)?;
-        self.hasher.update(&buf[..bytes_read]);
+        self.hasher.update(
+            buf.get(..bytes_read)
+                .expect("safe because bytes_read <= buf"),
+        );
         Ok(bytes_read)
     }
 }
 
 #[cfg(test)]
 mod test {
-    use super::HashingReader;
+    use std::io::Read;
+
     use rstest::rstest;
     use sha2::Sha256;
-    use std::io::Read;
+
+    use super::HashingReader;
 
     #[rstest]
     #[case(
@@ -208,8 +219,8 @@ mod test {
         "315f5bdb76d078c43b8ac0064e4a0164612b1fce77c869345bfc94c75894edd3"
     )]
     fn test_compute_file_sha256(#[case] input: &str, #[case] expected_hash: &str) {
-        // Write a known value to a temporary file and verify that the compute hash matches what we would
-        // expect.
+        // Write a known value to a temporary file and verify that the compute hash
+        // matches what we would expect.
 
         let temp_dir = tempfile::tempdir().unwrap();
         let file_path = temp_dir.path().join("test");
