@@ -9,7 +9,7 @@ use cache_control::{Cachability, CacheControl};
 use futures::{future::ready, FutureExt, TryStreamExt};
 use humansize::{SizeFormatter, DECIMAL};
 use rattler_digest::{compute_file_digest, Blake2b256, HashingWriter};
-use rattler_networking::retry_policies::default_retry_policy;
+use rattler_networking::{retry_policies::default_retry_policy, LazyClient};
 use rattler_redaction::Redact;
 use reqwest::{
     header::{HeaderMap, HeaderValue},
@@ -183,7 +183,7 @@ async fn repodata_from_file(
 #[instrument(err(level = Level::INFO), skip_all, fields(subdir_url, cache_path = % cache_path.display()))]
 pub async fn fetch_repo_data(
     subdir_url: Url,
-    client: reqwest_middleware::ClientWithMiddleware,
+    client: LazyClient,
     cache_path: PathBuf,
     options: FetchRepoDataOptions,
     reporter: Option<Arc<dyn Reporter>>,
@@ -293,7 +293,7 @@ pub async fn fetch_repo_data(
     let jlap_state = if has_jlap && cache_state.is_some() {
         let repo_data_state = cache_state.as_ref().unwrap();
         match jlap::patch_repo_data(
-            &client,
+            client.client(),
             subdir_url.clone(),
             repo_data_state.clone(),
             &repo_data_json_path,
@@ -352,7 +352,7 @@ pub async fn fetch_repo_data(
 
     // Construct the HTTP request
     tracing::debug!("fetching '{}'", &repo_data_url);
-    let request_builder = client.get(repo_data_url.clone());
+    let request_builder = client.client().get(repo_data_url.clone());
 
     let mut headers = HeaderMap::default();
 
@@ -657,7 +657,7 @@ impl VariantAvailability {
 /// Determine the availability of `repodata.json` variants (like a `.zst` or
 /// `.bz2`) by checking a cache or the internet.
 pub async fn check_variant_availability(
-    client: &reqwest_middleware::ClientWithMiddleware,
+    client: &LazyClient,
     subdir_url: &Url,
     cache_state: Option<&RepoDataState>,
     filename: &str,
@@ -761,10 +761,7 @@ pub async fn check_variant_availability(
 }
 
 /// Performs a HEAD request on the given URL to see if it is available.
-async fn check_valid_download_target(
-    url: &Url,
-    client: &reqwest_middleware::ClientWithMiddleware,
-) -> bool {
+async fn check_valid_download_target(url: &Url, client: &LazyClient) -> bool {
     tracing::debug!("checking availability of '{url}'");
 
     if url.scheme() == "file" {
@@ -778,7 +775,7 @@ async fn check_valid_download_target(
         exists
     } else {
         // Otherwise, perform a HEAD request to determine whether the url seems valid.
-        match client.head(url.clone()).send().await {
+        match client.client().head(url.clone()).send().await {
             Ok(response) => {
                 if response.status().is_success() {
                     tracing::debug!("'{url}' seems to be available");
@@ -1013,9 +1010,8 @@ mod test {
     use fs_err::tokio as tokio_fs;
     use futures::{stream, StreamExt};
     use hex_literal::hex;
-    use rattler_networking::AuthenticationMiddleware;
+    use rattler_networking::{AuthenticationMiddleware, LazyClient};
     use reqwest::Client;
-    use reqwest_middleware::{ClientBuilder, ClientWithMiddleware};
     use tempfile::TempDir;
     use tokio::{io::AsyncWriteExt, sync::Mutex};
     use tokio_util::io::ReaderStream;
@@ -1117,7 +1113,7 @@ mod test {
         let cache_dir = TempDir::new().unwrap();
         let result = fetch_repo_data(
             server.url(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.keep(),
             FetchRepoDataOptions::default(),
             None,
@@ -1147,7 +1143,7 @@ mod test {
         let cache_dir = TempDir::new().unwrap();
         let CachedRepoData { cache_result, .. } = fetch_repo_data(
             server.url(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.path().to_owned(),
             FetchRepoDataOptions::default(),
             None,
@@ -1160,7 +1156,7 @@ mod test {
         // Download the data from the channel with a filled cache.
         let CachedRepoData { cache_result, .. } = fetch_repo_data(
             server.url(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.path().to_owned(),
             FetchRepoDataOptions::default(),
             None,
@@ -1184,7 +1180,7 @@ mod test {
         // Download the data from the channel with a filled cache.
         let CachedRepoData { cache_result, .. } = fetch_repo_data(
             server.url(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.keep(),
             FetchRepoDataOptions::default(),
             None,
@@ -1213,7 +1209,7 @@ mod test {
         let cache_dir = TempDir::new().unwrap();
         let result = fetch_repo_data(
             server.url(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.keep(),
             FetchRepoDataOptions::default(),
             None,
@@ -1255,7 +1251,7 @@ mod test {
         let cache_dir = TempDir::new().unwrap();
         let result = fetch_repo_data(
             server.url(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.keep(),
             FetchRepoDataOptions::default(),
             None,
@@ -1304,7 +1300,7 @@ mod test {
         let cache_dir = TempDir::new().unwrap();
         let result = fetch_repo_data(
             server.url(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.keep(),
             FetchRepoDataOptions::default(),
             None,
@@ -1359,7 +1355,7 @@ mod test {
 
         let result = fetch_repo_data(
             server.url(),
-            authenticated_client,
+            authenticated_client.into(),
             cache_dir.keep(),
             FetchRepoDataOptions::default(),
             None,
@@ -1417,7 +1413,7 @@ mod test {
         let cache_dir = TempDir::new().unwrap();
         let _result = fetch_repo_data(
             server.url(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.keep(),
             FetchRepoDataOptions::default(),
             Some(reporter.clone()),
@@ -1440,7 +1436,7 @@ mod test {
         let result = fetch_repo_data(
             Url::parse(format!("file://{}", subdir_path.path().to_str().unwrap()).as_str())
                 .unwrap(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.keep(),
             FetchRepoDataOptions::default(),
             None,
@@ -1462,7 +1458,7 @@ mod test {
         let cache_dir = TempDir::new().unwrap();
         let result = fetch_repo_data(
             server.url(),
-            ClientWithMiddleware::from(Client::new()),
+            LazyClient::default(),
             cache_dir.keep(),
             FetchRepoDataOptions::default(),
             None,
@@ -1566,12 +1562,10 @@ mod test {
 
         let server_url = Url::parse(&format!("http://localhost:{}", addr.port())).unwrap();
 
-        let client = ClientBuilder::new(Client::default()).build();
-
         let cache_dir = TempDir::new().unwrap();
         let result = fetch_repo_data(
             server_url,
-            client,
+            LazyClient::default(),
             cache_dir.path().into(),
             FetchRepoDataOptions {
                 bz2_enabled: false,
