@@ -19,8 +19,7 @@ macro_rules! extern_sys {
 			$func:ident( $( $parm:ty ),* ) $( -> $ret:ty )?
 		)*
 	) => {
-		#[cfg_attr(not(feature = "raw-dylib"), link(name = $dll))]
-		#[cfg_attr(feature = "raw-dylib", link(name = $dll, kind = "raw-dylib"))]
+		#[link(name = $dll)]
 		extern "system" {
 			$(
 				one_func!( $func( $( $parm ),* ) $(-> $ret)? );
